# cellModel.py : Bann-and-Stick model 

from neuron import h
import math

class BallStickCell(object):

    def __init__(self):
        self.x = self.y = self.z = 0
        self.soma = h.Section(name='soma', cell=self)
        self.dend = h.Section(name='dend', cell=self)
        self.synlist = h.List()
        self.topol()
        self.subsets()
        self.geom()
        self.biophys()
        self.geom_nseg()
        self.synapses()

    def topol(self):
        self.dend.connect(self.soma(1))

    def subsets(self):
        self.all = h.SectionList()
        self.all.append(sec=self.soma)
        self.all.append(sec=self.dend)

    def geom(self):
        self.soma.L = self.soma.diam = 12.6157 # microns
        self.dend.L = 200                      # microns
        self.dend.diam = 1                     # microns
        
    def geom_nseg(self):
        for sec in self.all:
            sec.nseg = int((sec.L/(0.1*h.lambda_f(100))+.9)/2)*2 + 1 

    def biophys(self):
        for sec in self.all: # 'all' defined in build_subsets
            sec.Ra = 100    # Axial resistance in Ohm * cm
            sec.cm = 1      # Membrane capacitance in micro Farads / cm^2

        # Insert active Hodgkin-Huxley current in the soma
        self.soma.insert('hh')
        self.soma.gnabar_hh = 0.12  # Sodium conductance in S/cm2
        self.soma.gkbar_hh = 0.036  # Potassium conductance in S/cm2
        self.soma.gl_hh = 0.0003    # Leak conductance in S/cm2
        self.soma.el_hh = -54.3     # Reversal potential in mV
        # Insert passive current in the dendrite
        self.dend.insert('pas')
        self.dend.g_pas = 0.001  # Passive conductance in S/cm2
        self.dend.e_pas = -65    # Leak reversal potential mV
        
    def connect2target(self, pp):  
        nc = h.NetCon(self.soma(0.5)._ref_v, pp, sec=self.soma)
        nc.threshold = 10
        return nc

    def synapses (self):
        self.synlist.append(h.ExpSyn(0.8,sec=self.dend)) 
        self.synlist.object(0).tau = 2

        self.synlist.append(h.ExpSyn(0.1,sec=self.dend)) 
        self.synlist.object(1).tau = 5
        self.synlist.object(1).e = -80.0
