from neuron import h
import math

class BallAndStick(object):
    
    def __init__(self):
        self.x = self.y = self.z = 0
        self.soma = h.Section(name='soma', cell=self)
        self.dend = h.Section(name='dend', cell=self)
        self.synlist = h.List()
        self.topol()
        self.subsets()
        self.geom()
        self.biophys()
        self.geom_nseg()
        self.synapses()

    def topol(self):
        self.dend.connect(self.soma(1))
        self.basic_shape()

    def basic_shape(self):
        h.pt3dclear(sec=self.soma)
        h.pt3dadd( 0, 0, 0, 1, sec=self.soma)
        h.pt3dadd(15, 0, 0, 1, sec=self.soma)

        h.pt3dclear(sec=self.dend)
        h.pt3dadd( 15, 0, 0, 1, sec=self.dend)
        h.pt3dadd(105, 0, 0, 1, sec=self.dend)
    
    def subsets(self):
        self.all = h.SectionList()
        self.all.append(sec=self.soma)
        self.all.append(sec=self.dend)
        

    def geom(self):
        self.soma.L = self.soma.diam = 12.6157 # microns
        self.dend.L = 200                      # microns
        self.dend.diam = 1                     # microns
        
    def geom_nseg(self):
        for sec in self.all:
            sec.nseg = int((sec.L/(0.1*h.lambda_f(100))+.9)/2)*2 + 1 
    
    def biophys(self):
        for sec in self.all: # 'all' defined in build_subsets
            sec.Ra = 100    # Axial resistance in Ohm * cm
            sec.cm = 1      # Membrane capacitance in micro Farads / cm^2

        # Insert active Hodgkin-Huxley current in the soma
        self.soma.insert('hh')
        self.soma.gnabar_hh = 0.12  # Sodium conductance in S/cm2
        self.soma.gkbar_hh = 0.036  # Potassium conductance in S/cm2
        self.soma.gl_hh = 0.0003    # Leak conductance in S/cm2
        self.soma.el_hh = -54.3     # Reversal potential in mV
        # Insert passive current in the dendrite
        self.dend.insert('pas')
        self.dend.g_pas = 0.001  # Passive conductance in S/cm2
        self.dend.e_pas = -65    # Leak reversal potential mV

    def position(self, x, y, z):
        for sec in self.all:
            for i in range(int(h.n3d())):
                h.pt3dchange(i,
                        x - self.x + h.x3d(i),
                        y - self.y + h.y3d(i),
                        z - self.z + h.z3d(i),
                        h.diam3d(i))
        self.x, self.y, self.z = x, y, z
   
    def connect2target(self, pp): 
