# n04.py: soma + dendrite

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

tstop = 200.0
v_init = -65.0

soma = h.Section()
soma.diam = 30.0
soma.L = 30.0
soma.L = 30.0
soma.diam = 30.0
soma.nseg = 1
soma.insert('hh')

ap_dend = h.Section()
ap_dend.L = 500.0
ap_dend.diam = 2.0
ap_dend.nseg = 23
ap_dend.insert('hh')
ap_dend.gnabar_hh = 0.012
ap_dend.gkbar_hh = 0.0036
ap_dend.gl_hh = 0.00003

ap_dend.connect(soma, 1.0, 0.0)

ic = h.IClamp(0.5, sec=soma)
ic.delay = 20.0   # ms
ic.dur   = 100.0  # ms
ic.amp   = 0.5      # nA

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

tv = h.Vector()
vs = h.Vector()
va1 = h.Vector()
va2 = h.Vector()
cv = h.Vector()

tv.record(h._ref_t)
vs.record(soma(0.5)._ref_v)
va1.record(ap_dend(0.1)._ref_v)
va2.record(ap_dend(0.9)._ref_v)
cv.record(ic._ref_i)

h.finitialize(v_init)
h.fcurrent()
neuron.run(tstop)

ax = plt.subplot()
#ax.set_xlim([18.0,30.0])
ax.plot(tv.as_numpy(), vs.as_numpy())
ax.plot(tv.as_numpy(), va1.as_numpy())
ax.plot(tv.as_numpy(), va2.as_numpy())
ax.plot(tv.as_numpy(), 10.0*cv.as_numpy())
plt.xlabel('Time (ms)')
plt.ylabel('Potential (mV)')
plt.savefig('../figs/n04a.pdf')
plt.show()
