# n06.py excitatory and inhibitory inputs

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

tstop = 40.0
h.dt = 0.01
v_init = -65

soma = h.Section()
soma.L = 30.0
soma.diam = 30.0
soma.nseg = 1
soma.insert('hh')

ap_dend = h.Section()
ap_dend.L = 500.0
ap_dend.diam = 2.0
ap_dend.nseg = 23
ap_dend.insert('hh')
ap_dend.gnabar_hh = 0.012
ap_dend.gkbar_hh = 0.0036
ap_dend.gl_hh = 0.00003

ap_dend.connect(soma, 1.0, 0)

esyn = h.AlphaSynapse(0.1, sec = ap_dend)
esyn.onset = 10
esyn.tau   = 0.1
esyn.gmax  = 0.04
esyn.e     = 0.0

isyn_p = h.AlphaSynapse(0.05, sec = ap_dend)
isyn_p.onset = 5
isyn_p.tau = 3.0
isyn_p.e = -70 #v_init

isyn_d = h.AlphaSynapse(0.95, sec = ap_dend)
isyn_d.onset = 5
isyn_d.tau = 3.0
isyn_d.e = -70 #v_init

cvode = h.CVode()
cvode.active(1)
cvode.atol(1.0e-5)

tv = h.Vector()
vs = h.Vector()
tv.record(h._ref_t)
vs.record(soma(0.5)._ref_v)

tr = []
tt = []

for i in range(3):
    if i == 0:
        isyn_p.gmax = 0.0
        isyn_d.gmax = 0.0
    if i == 1:
        isyn_p.gmax = 0.03
        isyn_d.gmax = 0.0
    if i == 2:
        isyn_p.gmax = 0.0
        isyn_d.gmax = 0.03

    h.finitialize(v_init)
    h.fcurrent()
    while h.t < tstop:
        cvode.fixed_step()

    tt.append(np.copy(tv.as_numpy()))
    tr.append(np.copy(vs.as_numpy()))

ax = plt.subplot()
ax.set_ylim([-80,40])
ax.plot(tt[0], tr[0])
ax.plot(tt[1], tr[1])
ax.plot(tt[2], tr[2])
plt.xlabel('Time (ms)')
plt.ylabel('Potential (mV)')
plt.savefig('../figs/n06.pdf')
plt.show()
