#  n09.py: voltage clamp

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

tstop = 200.0
h.dt = 0.01
v_init = -65.0

soma = h.Section()
soma.L = 30.0
soma.diam = 30.0
soma.nseg = 1
soma.insert('hh')

esyn = h.Exp2Syn(0.5, sec=soma)
vcl = h.VClamp(0.5, sec=soma)

stim = h.NetStim(0.5)
stim.interval = 50
stim.number = 2
stim.start = 50
stim.noise = 0

vcl.dur[0] = 10.0
vcl.dur[1] = 10.0
vcl.dur[2] = 180.0
vcl.amp[0] = v_init
vcl.amp[1] = v_init
vcl.amp[2] = v_init
vcl.gain = 1000.0
vcl.tau1 = 0.01
vcl.tau2 = 0.01

nclist = []
nclist.append(h.NetCon(stim, esyn, 0.0, 0, 0.005))

tv = h.Vector()
vv = h.Vector()
cv = h.Vector()

tv.record(h._ref_t)
vv.record(soma(0.5)._ref_v)
cv.record(vcl._ref_i)

h.finitialize(v_init)
neuron.run(tstop)

ax = plt.subplot()
ax.set_ylim([-400,100])
ax.plot(tv.as_numpy(), 1000.0*cv.as_numpy())
ax.plot(tv.as_numpy(),vv.as_numpy())
plt.xlabel('Time (ms)')
plt.ylabel('Current')
plt.savefig('../figs/n09.pdf')
plt.show()
