# n10.py
# iv in voltage-clamp mode

from neuron import h
import neuron
import numpy as np
import matplotlib.pyplot as plt

tstop  = 50.0
h.dt   = 0.01
vstart = -100.0
vstep  = 10.0
ntrace = 20
npts   = int(tstop/h.dt)+1

soma = h.Section()
soma.diam = 30.0
soma.L = 30.0
soma.nseg = 1
soma.insert('pas')
    
vc = h.VClamp(0.5, sec=soma)
vc.dur[0] = 10.0
vc.dur[1] = 10.0
vc.dur[2] = 30.0

syn = h.Exp2Syn(0.5, sec=soma)
syn.e = 0

ns = h.NetStim()
ns.number = 1
ns.start = 10.0
ns.noise = 0

nc = []
nc.append(h.NetCon(ns, syn, 0, 0, 0.001))   # 1 nS

tv = h.Vector()
tv.record(h._ref_t)
cv = h.Vector()
cv.record(vc._ref_i)

taxes = []
traces = []
for i in range(ntrace):
    v_init = vstart + vstep * i
    vc.amp[0]=v_init
    vc.amp[1]=v_init
    vc.amp[2]=v_init
    soma.e_pas = v_init

    h.finitialize(v_init)
    h.fcurrent()
    neuron.run(tstop)
    traces.append(np.copy(cv.as_numpy()))
    taxes.append(np.copy(tv.as_numpy()))

#tt = tv.as_numpy()

ax = plt.subplot()
ax.set_ylim([-0.10,0.10])
for i in range(ntrace):
    ax.plot(taxes[i], traces[i])
#    ax.plot(tt, traces[i])
plt.xlabel('Time (ms)')
plt.ylabel('Current')

plt.savefig('../figs/n10.pdf')    
plt.show()
