#  n11.py
import subprocess
import numpy as np
import neuron
from neuron import h
import matplotlib.pyplot as plt

tstop = 200.0
h.dt = 0.01
v_init = -65.0
    
soma = h.Section()
dend = [h.Section() for i in range(10)]
    
soma.diam = 30.0
soma.L = 30.0
soma.Ra = 100.0
soma.nseg = 1
soma.insert('hh')
vcl = h.VClamp(0.5, sec=soma)

for i in range(10):
    dend[i].L = 300.0
    dend[i].Ra = 100.0
    dend[i].nseg = 21
    dend[i].diam = 2.0
    dend[i].insert('hh')
    dend[i].gl_hh *= 2.3
    dend[i].connect(soma, 1.0, 0.0)
		
esyn = h.Exp2Syn(0.75, sec=dend[0])
	
# stimulation
stim = h.NetStim(0.5)
stim.interval = 50.0
stim.number = 2
stim.start = 50.0
stim.noise = 0

# synaptic connections
nclist = []
nclist.append(h.NetCon(stim, esyn, 0.0, 0, 0.001))

vcl.dur[0] = 10.0
vcl.dur[1] = 10.0
vcl.dur[2] = 180.0
vcl.amp[0] = v_init
vcl.amp[1] = v_init
vcl.amp[2] = v_init
vcl.gain = 1000.0
vcl.tau1 = 0.1
vcl.tau2 = 0.1
	
tv = h.Vector()
vs = h.Vector()
vd = h.Vector()
cv = h.Vector()

tv.record(h._ref_t)
vs.record(soma(0.5)._ref_v)
vd.record(dend[0](0.75)._ref_v)
cv.record(vcl._ref_i)

h.finitialize(v_init)
h.fcurrent()
neuron.run(tstop)

ax = plt.subplot()
ax.set_ylim([-70.0, -35.0])
ax.plot(tv.as_numpy(), 100*cv.as_numpy())
ax.plot(tv.as_numpy(), vs.as_numpy())
ax.plot(tv.as_numpy(), vd.as_numpy())
plt.xlabel('Time (ms)')
plt.ylabel('Current')
plt.savefig('../figs/n11.pdf')    
plt.show()
