# n19.py
 
import neuron
from neuron import h
import numpy as np
import matplotlib.pyplot as plt

class InvlFire(object):	
    def __init__(self):
        self.cell = h.Section()
        self.IF = h.IntervalFire(0.5, sec=self.cell)
        self.IF.tau  = 5.0
        self.IF.invl = 10.0
        self.synlist = h.List()


tstop = 100.0
h.dt = 0.1

ce = InvlFire()

# external stimulation
stim = h.NetStim()
stim.number = 40
stim.start = 25
stim.interval = 1

ncstim = h.NetCon(stim, ce.IF)
ncstim.delay= 0
ncstim.weight[0] = 0.07

# record for spikes
nc = h.NetCon(ce.IF, None)
stvec = h.Vector( )
nc.record(stvec)

# run control
h.finitialize()
tt = []
mm = []
MM = []
while h.t < tstop:
    tt.append(h.t)
    mm.append(ce.IF.m)
    MM.append(ce.IF.M())
    h.fadvance()

f, ax = plt.subplots(2, sharex=True)
ax[0].plot(tt, mm)
ax[0].plot(tt, MM)
ax[0].set_ylabel('Values of m and M')

ax[1].eventplot(stvec.as_numpy())
ax[1].set_xlabel('Time (ms)')
ax[1].set_ylabel('Events')

plt.savefig('../figs/n19.pdf')  
plt.show()
